.. decent_bench documentation master file, created by
   sphinx-quickstart on Mon Sep  1 21:05:43 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to decent-bench's documentation!
========================================


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   API Reference <api/decent_bench>
   Developer Guide <developer>
